/*= Rohde & Schwarz - Signal Generator SMP ==================================*/

/*===========================================================================*/
/*  Please do not use global variables or arrays in the include file of      */
/*  instrument drivers that will be submitted for inclusion into the         */
/*  LabWindows Instrument Driver Library.                                    */
/*===========================================================================*/
     
#ifndef __rssmp_HEADER
#define __rssmp_HEADER

#include <vpptype.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

#define PI                              3.1416
#define BYTE_LEN                        8
#define NAME_LEN                        7
#define rssmp_NUMB_OF_AVAILABLE_OPTIONS     15

#define SMP									0
#define SMR									1

/*****************************************************************************/
/*= Define Instrument Specific Error Codes Here =============================*/
/*****************************************************************************/
#define VI_ERROR_INSTR_FILE_OPEN                (_VI_ERROR+0x3FFC0800L)
#define VI_ERROR_INSTR_FILE_WRITE               (_VI_ERROR+0x3FFC0801L)
#define VI_ERROR_INSTR_INTERPRETING_RESPONSE    (_VI_ERROR+0x3FFC0803L)
#define VI_ERROR_INSTR_PARAMETER9               (_VI_ERROR+0x3FFC0809L)
#define VI_ERROR_INSTR_PARAMETER10              (_VI_ERROR+0x3FFC080AL)
#define VI_ERROR_INSTR_PARAMETER11              (_VI_ERROR+0x3FFC080BL)
#define VI_ERROR_INSTR_PARAMETER12              (_VI_ERROR+0x3FFC080CL)
#define VI_ERROR_INSTR_PARAMETER13              (_VI_ERROR+0x3FFC080DL)
#define VI_ERROR_INSTR_PARAMETER14              (_VI_ERROR+0x3FFC080EL)
#define VI_ERROR_INSTR_PARAMETER15              (_VI_ERROR+0x3FFC080FL)

/*****************************************************************************/
/*= Define Instrument Specific Error/Warning Codes Here =====================*/
/*****************************************************************************/
#define VI_WARNING_INSTR_OFFSET                           (0x3FFC0900L)
#define VI_ERROR_INSTR_OFFSET                   (_VI_ERROR+0x3FFC0900L)

#define rssmp_VI_WARN_NSUP_OPTION               (VI_WARNING_INSTR_OFFSET+0x00L)
#define rssmp_VI_WARN_NSUP_FUNCTION				(VI_WARNING_INSTR_OFFSET+0x01L)
#define rssmp_ERROR_INSTRUMENT_ERROR            (VI_ERROR_INSTR_OFFSET + 0x00L)

/*****************************************************************************/
/*= GLOBAL USER-CALLABLE FUNCTION DECLARATIONS (Exportable Functions) =======*/
/*****************************************************************************/
ViStatus _VI_FUNC rssmp_init (ViRsrc resourceName, ViBoolean IDQuery,
                              ViBoolean resetDevice, ViPSession instrumentHandle);
ViStatus _VI_FUNC rssmp_applicOutpAmplModul (ViSession instrumentHandle,
                                             ViReal64 carrierFrequencyMHz,
                                             ViReal64 carrierLeveldBm,
                                             ViReal64 depth,
                                             ViBoolean internalSource,
                                             ViReal64 frequencyHz, ViInt16 shape);
ViStatus _VI_FUNC rssmp_confCarrFreq (ViSession instrumentHandle,
                                      ViReal64 frequencyMHz, ViReal64 offsetMHz,
                                      ViReal64 multiplier, ViBoolean operatingMode);
ViStatus _VI_FUNC rssmp_confCarrLevel (ViSession instrumentHandle, ViReal64 level,
                                       ViReal64 offsetdB, ViReal64 levelLimit,
                                       ViInt16 unit, ViBoolean operatingMode,
                                       ViBoolean attenuator);
ViStatus _VI_FUNC rssmp_confALC (ViSession instrumentHandle, ViBoolean ALCState,
                                 ViBoolean pmeterType, ViInt16 search,
                                 ViInt16 source, ViReal64 reference);
ViStatus _VI_FUNC rssmp_confUserCorr (ViSession instrumentHandle,
                                      ViBoolean correctionState, ViInt16 corrList,
                                      ViString corrListName,
                                      ViReal64 _VI_FAR frequencyHz[],
                                      ViReal64 _VI_FAR leveldB[],
                                      ViInt32 corrListLength);
ViStatus _VI_FUNC rssmp_confAmplModul (ViSession instrumentHandle,
                                       ViBoolean AMState, ViInt16 modulationSource,
                                       ViReal64 depth);
ViStatus _VI_FUNC rssmp_confFreqModul (ViSession instrumentHandle,
                                       ViBoolean FM1State, ViBoolean FM2State,
                                       ViInt16 FMMode, ViReal64 FM1DeviationHz,
                                       ViReal64 FM2DeviationHz,
                                       ViInt16 FM1ModulationSource,
                                       ViInt16 FM2ModulationSource);
ViStatus _VI_FUNC rssmp_confPhasModul (ViSession instrumentHandle,
                                       ViBoolean PM1State, ViReal64 PM1Deviation,
                                       ViBoolean PM2State, ViReal64 PM2Deviation,
                                       ViBoolean unit, ViInt16 PM1ModulationSource,
                                       ViInt16 PM2ModulationSource);
ViStatus _VI_FUNC rssmp_confPulsModul (ViSession instrumentHandle,
                                       ViBoolean pulseModulationState,
                                       ViBoolean polarity,
                                       ViBoolean extImpedanceOhm,
                                       ViReal64 pulseWidths, ViReal64 pulseDelays,
                                       ViReal64 pulsePeriodFreq,
                                       ViBoolean pulseParameter,
                                       ViBoolean pulseShape,
                                       ViBoolean modulationSource);
ViStatus _VI_FUNC rssmp_confDigitModul (ViSession instrumentHandle,
                                        ViBoolean modulationType,
                                        ViBoolean modulationState,
                                        ViBoolean polarity, ViReal64 FSKDeviationHz,
                                        ViInt16 FSKMode, ViReal64 ASKDepth);
ViStatus _VI_FUNC rssmp_confExtInput (ViSession instrumentHandle,
                                      ViBoolean ext1Coupling,
                                      ViBoolean ext2Coupling,
                                      ViBoolean ext1Impedance,
                                      ViBoolean ext2Impedance);
ViStatus _VI_FUNC rssmp_confFreqSweep (ViSession instrumentHandle,
                                       ViInt16 sweepMode, ViInt16 freqInputMode,
                                       ViReal64 startFrequencyMHz,
                                       ViReal64 stopFrequencyMHz,
                                       ViReal64 centerFrequencyMHz,
                                       ViReal64 frequencySpanMHz,
                                       ViReal64 dwellTimes, ViReal64 stepWidth,
                                       ViBoolean spacing);
ViStatus _VI_FUNC rssmp_confFreqSweepMrks (ViSession instrumentHandle,
                                           ViReal64 m1FrequencyMHz,
                                           ViReal64 m2FrequencyMHz,
                                           ViReal64 m3FrequencyMHz,
                                           ViBoolean m1State, ViBoolean m2State,
                                           ViBoolean m3State, ViBoolean amplitudeM1,
                                           ViBoolean amplitudeM2,
                                           ViBoolean amplitudeM3,
                                           ViBoolean polarity);
ViStatus _VI_FUNC rssmp_confLevelSweep (ViSession instrumentHandle,
                                        ViInt16 sweepMode, ViReal64 startLevel,
                                        ViReal64 stopLevel, ViInt16 unit,
                                        ViReal64 dwellTimes, ViReal64 stepWidthdB);
ViStatus _VI_FUNC rssmp_confLevelSweepMrks (ViSession instrumentHandle,
                                            ViReal64 m1Level, ViReal64 m2Level,
                                            ViReal64 m3Level, ViBoolean m1State,
                                            ViBoolean m2State, ViBoolean m3State,
                                            ViBoolean polarity);
ViStatus _VI_FUNC rssmp_confLFGen (ViSession instrumentHandle, ViBoolean source,
                                   ViReal64 voltageV, ViReal64 LFGen1FrequencyHz,
                                   ViInt16 LFGen1Shape, ViReal64 LFGen2FrequencyHz,
                                   ViInt16 LFGen2Shape, ViBoolean LFGen2Mode);
ViStatus _VI_FUNC rssmp_confLFSweep (ViSession instrumentHandle, ViInt16 sweepMode,
                                     ViReal64 startFrequencyHz,
                                     ViReal64 stopFrequencyHz, ViBoolean spacing,
                                     ViReal64 stepWidth, ViReal64 dwellTimes);
ViStatus _VI_FUNC rssmp_confLFSweepMrks (ViSession instrumentHandle,
                                         ViReal64 m1FrequencyHz,
                                         ViReal64 m2FrequencyHz,
                                         ViReal64 m3FrequencyHz, ViBoolean m1State,
                                         ViBoolean m2State, ViBoolean m3State,
                                         ViBoolean polarity);
ViStatus _VI_FUNC rssmp_confSaveRecallSetup (ViSession instrumentHandle,
                                             ViInt32 setupNumber,
                                             ViBoolean setupMode);
ViStatus _VI_FUNC rssmp_confEditCatalog (ViSession instrumentHandle, ViInt16 action,
                                         ViChar _VI_FAR oldCatalogContent[],
                                         ViPInt32 oldOccupiedMemory,
                                         ViPInt32 oldVacantMemory,
                                         ViString name,
                                         ViChar _VI_FAR newCatalogContent[],
                                         ViPInt32 newOccupiedMemory,
                                         ViPInt32 newVacantMemory, ViBoolean setup);
ViStatus _VI_FUNC rssmp_confCreateLst (ViSession instrumentHandle,
                                       ViString listName,
                                       ViInt16 listLength,
                                       ViReal64 _VI_FAR frequency[],
                                       ViReal64 _VI_FAR level[],
                                       ViReal64 dwellTimes);
ViStatus _VI_FUNC rssmp_confCreateMemSeq (ViSession instrumentHandle,
                                          ViString sequenceName,
                                          ViInt32 sequenceLength,
                                          ViInt32 _VI_FAR setupList[],
                                          ViReal64 _VI_FAR dwellLists[]);
ViStatus _VI_FUNC rssmp_confSelLstSeq (ViSession instrumentHandle,
                                       ViInt16 setupMode, ViBoolean stepMode,
                                       ViString seqListName);
ViStatus _VI_FUNC rssmp_confTrigger (ViSession instrumentHandle,
                                     ViInt16 triggerType, ViInt16 triggerSource,
                                     ViInt16 extTriggerSlope,
                                     ViBoolean extAbortPolarity);
ViStatus _VI_FUNC rssmp_confOPTLst (ViSession instrumentHandle,
                                    ViChar _VI_FAR optionsList[],
                                    ViChar _VI_FAR instrumentVersion[]);
ViStatus _VI_FUNC rssmp_confRefOscillator (ViSession instrumentHandle,
                                           ViBoolean referenceSource,
                                           ViBoolean phaseAdjustment,
                                           ViBoolean unit, ViReal64 deltaPhase,
                                           ViBoolean frequencyAdjustment,
                                           ViInt32 externalFrequencyMHz,
                                           ViInt32 frequencyCorrection);
ViStatus _VI_FUNC rssmp_confAuxOut (ViSession instrumentHandle,
                                    ViBoolean blankPolarity, ViBoolean blankTime,
                                    ViBoolean VGHzScale,
                                    ViReal64 ZAxisBlankVoltageV,
                                    ViReal64 ZAxisMarkerVoltageV);
ViStatus _VI_FUNC rssmp_confBeep (ViSession instrumentHandle, ViBoolean beeperState);
ViStatus _VI_FUNC rssmp_qRFfrequency (ViSession instrumentHandle,
                                      ViReal64 RFFrequencyinMHz,
                                      ViBoolean checkRange);
ViStatus _VI_FUNC rssmp_qRFlevel (ViSession instrumentHandle, ViReal64 RFLevelindBm,
                                  ViBoolean checkRange);
ViStatus _VI_FUNC rssmp_qRFlevOffset (ViSession instrumentHandle,
                                      ViReal64 levelOffsetindB,
                                      ViBoolean checkRange);
ViStatus _VI_FUNC rssmp_qRFstartStopFreq (ViSession instrumentHandle,
                                          ViReal64 startFreqinMHz,
                                          ViReal64 stopFreqinMHz,
                                          ViBoolean checkRange);
ViStatus _VI_FUNC rssmp_qRFcenterSpanFreq (ViSession instrumentHandle,
                                           ViReal64 centerFreqinMHz,
                                           ViReal64 spanFreqinMHz,
                                           ViBoolean checkRange);
ViStatus _VI_FUNC rssmp_qRFsweepStep (ViSession instrumentHandle,
                                      ViReal64 stepWidth, ViBoolean checkRange);
ViStatus _VI_FUNC rssmp_qLFfreq (ViSession instrumentHandle, ViBoolean LFGenerator,
                                 ViReal64 frequencyinHz, ViBoolean checkRange);
ViStatus _VI_FUNC rssmp_qLFvolt (ViSession instrumentHandle, ViReal64 voltageinV,
                                 ViBoolean checkRange);
ViStatus _VI_FUNC rssmp_qAMmodDep (ViSession instrumentHandle,
                                   ViReal64 modulationDepthin, ViBoolean checkRange);
ViStatus _VI_FUNC rssmp_qFMdev (ViSession instrumentHandle, ViBoolean modulator,
                                ViReal64 freqDeviationinHz, ViBoolean checkRange);
ViStatus _VI_FUNC rssmp_qPHMdev (ViSession instrumentHandle, ViBoolean modulator,
                                 ViReal64 phaseDeviationinrad, ViBoolean checkRange);
ViStatus _VI_FUNC rssmp_qPulsModDelay (ViSession instrumentHandle,
                                       ViReal64 pulseDelays, ViBoolean checkRange);
ViStatus _VI_FUNC rssmp_qPulsModPeriod (ViSession instrumentHandle,
                                        ViReal64 pulsePeriod, ViBoolean checkRange);
ViStatus _VI_FUNC rssmp_qPulsModWidth (ViSession instrumentHandle,
                                       ViReal64 pulseWidths, ViBoolean checkRange);
ViStatus _VI_FUNC rssmp_outState (ViSession instrumentHandle, ViBoolean RFOutput,
                                  ViBoolean LFOutput, ViBoolean VGHzOutput);
ViStatus _VI_FUNC rssmp_sendTrig (ViSession instrumentHandle, ViInt16 triggerType);
ViStatus _VI_FUNC rssmp_abort (ViSession instrumentHandle, ViInt16 abort);
ViStatus _VI_FUNC rssmp_operationComplete (ViSession instrumentHandle,
                                           ViInt32 maxTimeouts);
ViStatus _VI_FUNC rssmp_step (ViSession instrumentHandle, ViBoolean stepMode,
                              ViBoolean direction, ViInt16 parameter,
                              ViReal64 stepSize);
ViStatus _VI_FUNC rssmp_writeInstrData (ViSession instrumentHandle,
                                        ViString writeBuffer);
ViStatus _VI_FUNC rssmp_readInstrData (ViSession instrumentHandle,
                                       ViInt16 numberBytesToRead,
                                       ViChar _VI_FAR readBuffer[],
                                       ViPInt32 numBytesRead);
ViStatus _VI_FUNC rssmp_reset (ViSession instrumentHandle);
ViStatus _VI_FUNC rssmp_self_test (ViSession instrSession, ViPInt16 result,
                                   ViChar _VI_FAR message[]);
ViStatus _VI_FUNC rssmp_error_query (ViSession instrumentHandle, ViPInt32 errorCode,
                                    ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rssmp_error_message (ViSession instrumentHandle,
                                      ViStatus errorCode,
                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rssmp_revision_query (ViSession instrumentHandle,
                                       ViChar _VI_FAR instrumentDriverRevision[],
                                       ViChar _VI_FAR firmwareRevision[]);
ViStatus _VI_FUNC rssmp_close (ViSession instrumentHandle);


#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/

#endif
